Changes
=======

2.0a1 (2023-05-15)
------------------

- Add ``webresource`` support.
  [rnix]

- Extend JS by ``ace_on_array_add`` and ``register_array_subscribers``
  to enable usage in ``yafowil.widget.array``.
  [lenadax]

- Update ACE Editor to v1.4.13.
  [rnix]

- Rewrite JavaScript using ES6.
  [rnix]


1.2 (2018-07-16)
----------------

- Python 3 compatibility.
  [rnix]

- Convert doctests to unittests.
  [rnix]


1.1 (2017-03-01)
----------------

- Use ``yafowil.utils.entry_point`` decorator.
  [rnix]


1.0.1 (2015-01-23)
------------------

- Cleanup examples.
  [rnix]

1.0
---

- Make it work.
  [rnix]
